Re-exports
pub use backend::BackendAuthMode;pub use backend::BackendServerConfig;pub use backend::BackendTransport;pub use compressed::BackendConfigSource;pub use compressed::CompressedServer;pub use compressed::CompressedServerConfig;pub use compressed::JustBashCommandSpec;pub use compressed::JustBashProviderSpec;pub use compressed::ProxyTransformMode;pub use tool_cache::ToolCache;
Modules
- backend
- compressed
CompressedServer— the top-level object that owns the backend client, tool cache, and compression engine, and exposes them via a frontend MCP server.- registration
- Frontend MCP server registration for compressed wrapper tools.
- tool_
cache ToolCache— lazily populated, refresh-on-demand tool schema store.